
declare
v_grid_name varchar2(10);
v_grid_id number(14);
v_grid_desc varchar2(40);
v_field_id number(14);
v_field_id_list VARCHAR2(1000);
v_grid_key_fields VARCHAR2(200);
v_dataspy_id number(14);
v_bot_number number(14);
v_field_source_name varchar2(100);
v_field_tag_name varchar2(100);
v_language VARCHAR2(2);
r5boilertexts_exists integer;
r5grid_exists integer;
r5functions_exists integer;
sequence_check varchar2(3);

begin

-------------------------------------------------------------------------------
-- Set custom grid name
-------------------------------------------------------------------------------

v_grid_name := 'AUI004'; 
v_language := '&1';

-------------------------------------------------------------------------------
-- Cleanup existing r5boilertexts
-------------------------------------------------------------------------------

select count(*) into r5boilertexts_exists
from r5boilertexts
where BOT_FUNCTION = v_grid_name
and rownum = 1;

IF r5boilertexts_exists = 1 THEN
	DELETE FROM r5boilertexts where BOT_FUNCTION = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Cleanup existing r5grid and related data
-------------------------------------------------------------------------------

select count(*) into r5grid_exists
from r5grid
where GRD_GRIDNAME = v_grid_name
and rownum = 1;

IF r5grid_exists = 1 THEN
	DELETE FROM r5queryfield where DQF_DDSPYID in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
	DELETE FROM r5usegridsysdefault where usd_dataspyid in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
    DELETE FROM R5dddataspy WHERE DDS_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridfield where GFD_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridparam where GDP_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5grid WHERE GRD_GRIDNAME = v_grid_name;
END IF;


-------------------------------------------------------------------------------
-- Cleanup existing r5functions
-------------------------------------------------------------------------------

select count(*) into r5functions_exists
from r5functions
where FUN_CODE = v_grid_name
and rownum = 1;

IF r5functions_exists = 1 THEN
  DELETE FROM R5EXTMENULANG WHERE EML_EXTMENU IN (SELECT EMN_CODE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name);
  DELETE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name;
  DELETE FROM r5functions where FUN_CODE = v_grid_name;
END IF;


-------------------------------------------------------------------------------
--Insert r5functions
-------------------------------------------------------------------------------
INSERT INTO R5FUNCTIONS (FUN_CODE,FUN_DESC,FUN_CLASS,FUN_SUBTYPE,FUN_FILE,FUN_PUBLIC,FUN_SELECT,FUN_BACKGROUND,FUN_APPLICATION,FUN_DIRSEL,FUN_SYSTEM,FUN_DISPLAYAP,FUN_DISPLAYFT,FUN_POPUPAP,FUN_POPUPFT,FUN_DESCCHANGED,FUN_CLASS_ORG,FUN_RS,FUN_LST,FUN_HDR,FUN_EWSREPORT,FUN_PRDDATASRC,FUN_EWSURLNEW,FUN_REPDISABLED,FUN_ADVREPT,FUN_MEKEY,FUN_EWSBTN)
 VALUES (v_grid_name,'Inventory Parts (AM)','WEBD','M','R5MENU','-','?','-','BSUGRD','-','+','-','+','-','-','-','*','-','+','-','-','-','-','-','-','YN','-');

-------------------------------------------------------------------------------
-- Insert r5grid
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_grid_id, 'GRD', '1', sequence_check);
INSERT INTO R5GRID (GRD_DESC,GRD_GRIDID,GRD_BASEQUERY,GRD_GRIDNAME,GRD_BOTFUNCTION,GRD_PORTLETFLAG,GRD_TAB,GRD_GRIDTYPE,GRD_OPTIMIZERON,GRD_DISTINCT,GRD_COMPLEX,GRD_ACTIVE,GRD_NOSCREENDESIGNER)
 VALUES ('Inventory Parts (AM)',v_grid_id,'SELECT <FIELDLIST_1> 
FROM r5transactions t, r5stocktakelines s, r5descriptions d, r5parts p
WHERE t.tra_code = :param.inventorycode
AND        t.tra_rstatus <> ''A''
AND        s.stl_trans = t.tra_code
AND        d.des_rentity (+) = ''PART''
AND        d.des_code (+) = s.stl_part
AND        d.des_org (+) = s.stl_part_org
AND        d.des_lang (+) = :parameter.language
AND        p.par_code = s.stl_part
AND        p.par_org = s.stl_part_org
<FILTER_1> 
UNION 
SELECT <FIELDLIST_2> 
FROM r5transactions t1, r5translines t2, r5descriptions d, r5parts p
WHERE t1.tra_code = :param.inventorycode
AND        t1.tra_rstatus = ''A''
AND        t2.trl_trans = t1.tra_code
AND        d.des_rentity (+) = ''PART''
AND        d.des_code (+) = t2.trl_part
AND        d.des_org (+) = t2.trl_part_org
AND        d.des_lang (+) = :parameter.language
AND        p.par_code = t2.trl_part
AND        p.par_org = t2.trl_part_org
<FILTER_2> 
<SORT_BY>',v_grid_name,v_grid_name,'-','+',2,'-','-','-','+','-');

-------------------------------------------------------------------------------
-- Insert r5dddataspy
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_dataspy_id, 'DDS', '1', sequence_check);
INSERT INTO R5DDDATASPY (DDS_DDSPYNAME,DDS_DDSPYID,DDS_SCOPE,DDS_ORGANIZATION,DDS_CREATEDSTAMP,DDS_FILTERSTRXML,DDS_SORTSTRXML,DDS_OWNER,DDS_GRIDID,DDS_TYPE,DDS_DEFAULTFLAG,DDS_CLIENTROWS,DDS_BOTNAME,DDS_SECURITYDATASPY,DDS_MEKEY)
 VALUES ('All Records',v_dataspy_id,'-','*',sysdate,'<FILTERABLE />','<SORTABLE><SORT_ELEMENT ALIAS_NAME="linenumber" SEQNUM="1" TYPE="ASC"/></SORTABLE>','R5',v_grid_id,'SD','+',30,'DSNAME','-','YY');

-------------------------------------------------------------------------------
-- Insert the three base r5boilertexts
-- Note: You must also insert a r5boilertext record for each "grid field" (see below)
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,1,100,0,0,v_language,'List View','TB','1','LST','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,2,100,0,0,v_language,'Inventory Parts (AM)','F','1','UDG_HDRLABEL','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,3,100,0,0,v_language,'All Records','F','1','DSNAME','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,4,100,0,0,v_language,'bincode','F','1','bincode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,5,100,0,0,v_language,'expectedquantity','F','1','expectedquantity','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,6,100,0,0,v_language,'hiddenqty','F','1','hiddenqty','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,7,100,0,0,v_language,'linenumber','F','1','linenumber','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,8,100,0,0,v_language,'lotcode','F','1','lotcode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,9,100,0,0,v_language,'manufacturer','F','1','manufacturer','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,10,100,0,0,v_language,'manufacturerpartnumber','F','1','manufacturerpartnumber','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,11,100,0,0,v_language,'messagecolumn','F','1','messagecolumn','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,12,100,0,0,v_language,'partcode','F','1','partcode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,13,100,0,0,v_language,'partdescription','F','1','partdescription','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,14,100,0,0,v_language,'partorganization','F','1','partorganization','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,15,100,0,0,v_language,'physicalinventorycode','F','1','physicalinventorycode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,16,100,0,0,v_language,'physicalquantity','F','1','physicalquantity','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,17,100,0,0,v_language,'recordid','F','1','recordid','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,18,100,0,0,v_language,'rstatus','F','1','rstatus','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,19,100,0,0,v_language,'store','F','1','store','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,20,100,0,0,v_language,'storeorganization','F','1','storeorganization','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,22,100,0,0,v_language,'partuom','F','1','partuom','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,23,100,0,0,v_language,'trackbyasset','F','1','trackbyasset','10000',sysdate,'-');

-------------------------------------------------------------------------------
-- Copy the R5BOILERTEXTS for each of the languages in the R5LANGINST
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED)
SELECT BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,LIN_CODE,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED
FROM R5BOILERTEXTS, R5LANGINST
WHERE
BOT_LANG = v_language AND BOT_FUNCTION = v_grid_name AND lin_code <> v_language;

-------------------------------------------------------------------------------
-- Insert r5ddfield, r5gridfield, r5queryfield for each grid field
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_bin','VARCHAR','LVBINALL;gridtagname=CODE','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,4,'TEXT','bincode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',1,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_bin','VARCHAR','LVBINALL;gridtagname=CODE','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,4,'TEXT','bincode','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',1,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_expqty','DECIMAL','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,5,'TEXT','expectedquantity','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',2,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_origqty','DECIMAL','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,5,'TEXT','expectedquantity','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',2,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'STL_PHYQTY','DECIMAL','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,6,'TEXT','hiddenqty','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',3,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'t2.trl_qty','DECIMAL','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,6,'TEXT','hiddenqty','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',3,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_line','NUMBER','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,7,'TEXT','linenumber','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',4,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_line','NUMBER','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,7,'TEXT','linenumber','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',4,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_lot','VARCHAR','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,8,'TEXT','lotcode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',5,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_lot','VARCHAR','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,8,'TEXT','lotcode','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',5,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'STL_MANUFACTURER','VARCHAR','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,9,'TEXT','manufacturer','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',6,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'TRL_MANUFACTURER','VARCHAR','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,9,'TEXT','manufacturer','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',6,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'STL_MANUFACTPART','MIXVARCHAR','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,10,'TEXT','manufacturerpartnumber','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',7,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'TRL_MANUFACTPART','MIXVARCHAR','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,10,'TEXT','manufacturerpartnumber','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',7,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'''''','VARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,11,'TEXT','messagecolumn','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',8,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'''''','VARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,11,'TEXT','messagecolumn','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',8,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_part','VARCHAR','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,12,'TEXT','partcode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',9,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_part','VARCHAR','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,12,'TEXT','partcode','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',9,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'d.des_text','MIXVARCHAR','','R5DESCRIPTIONS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,13,'TEXT','partdescription','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',10,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'des_text','MIXVARCHAR','','R5DESCRIPTIONS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,13,'TEXT','partdescription','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',10,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_part_org','VARCHAR','LVORGALL;gridtagname=organization','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,14,'TEXT','partorganization','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',11,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_part_org','VARCHAR','LVORGALL;gridtagname=organization','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,14,'TEXT','partorganization','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',11,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'p.par_uom','MIXVARCHAR','','R5PARTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,22,'TEXT','partuom','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',18,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'par_uom','MIXVARCHAR','','R5PARTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,22,'TEXT','partuom','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',18,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_trans','VARCHAR','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,15,'TEXT','physicalinventorycode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',12,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_trans','VARCHAR','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,15,'TEXT','physicalinventorycode','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',12,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_phyqty','DECIMAL','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,16,'TEXT','physicalquantity','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',13,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_origqty-trl_qty','DECIMAL','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,16,'TEXT','physicalquantity','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',13,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'stl_updatecount','NUMBER','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,17,'TEXT','recordid','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',14,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_updatecount','NUMBER','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,17,'TEXT','recordid','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',14,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'t.tra_rstatus','VARCHAR','','R5TRANSACTIONS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,18,'TEXT','rstatus','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',15,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'TRA_RSTATUS','VARCHAR','','R5TRANSACTIONS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,18,'TEXT','rstatus','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',15,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'s.stl_store','VARCHAR','','R5STOCKTAKELINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,19,'TEXT','store','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',16,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'trl_store','VARCHAR','','R5TRANSLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,19,'TEXT','store','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',16,'LIST'); 

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'t.tra_org','VARCHAR','LVORGALL;gridtagname=organization','R5TRANSACTIONS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,20,'TEXT','storeorganization','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',17,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'TRA_ORG','VARCHAR','LVSORGALL;gridtagname=organization','R5TRANSACTIONS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,20,'TEXT','storeorganization','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',17,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'NVL(PAR_BYASSET, ''-'')','CHKBOOLEAN','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,23,'CHECKBOX','trackbyasset','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',19,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'DECODE(p.par_byasset, ''+'', ''+'', ''-'')','CHKBOOLEAN','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,23,'CHECKBOX','trackbyasset','n',2,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',19,'LIST');
 
-------------------------------------------------------------------------------
-- Insert r5gridparam
-------------------------------------------------------------------------------
INSERT INTO R5GRIDPARAM (GDP_GRIDID,GDP_PARAM)
 VALUES (v_grid_id,'parameter.language');

INSERT INTO R5GRIDPARAM (GDP_GRIDID,GDP_PARAM, GDP_DATATYPE)
 VALUES (v_grid_id,':param.inventorycode', 'String');

-------------------------------------------------------------------------------
-- Setup field keys on r5grid
-------------------------------------------------------------------------------

update r5grid set 
grd_keyfields = v_grid_key_fields, 
grd_filterablelist = v_field_id_list,
grd_sortablelist = v_field_id_list,
grd_displayablelist = v_field_id_list
where grd_gridid = v_grid_id;

commit;

end;

/
